﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.Services.Hive.Common.DataTransfer;

namespace HeuristicLab.Clients.Hive.Views {
  [View("StateLogGanttChart View")]
  [Content(typeof(StateLogItemList), IsDefaultView = false)]
  public sealed partial class StateLogGanttChartView : ItemView {
    public new StateLogItemList Content {
      get { return (StateLogItemList)base.Content; }
      set { base.Content = value; }
    }

    public StateLogGanttChartView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      // Deregister your event handlers here
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      // Register your event handlers here
    }

    #region Event Handlers (Content)
    // Put event handlers of the content here
    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        // Add code when content has been changed and is null
        ganttChart.Reset();
      } else {
        // Add code when content has been changed and is not null
        ganttChart.Reset();
        ganttChart.AddCategory(JobState.Offline.ToString(), Color.Brown);
        ganttChart.AddCategory(JobState.Waiting.ToString(), Color.Yellow);
        ganttChart.AddCategory(JobState.Transferring.ToString(), Color.Blue);
        ganttChart.AddCategory(JobState.Calculating.ToString(), Color.Green);
        ganttChart.AddCategory(JobState.Finished.ToString(), Color.DarkGreen);
        ganttChart.AddCategory(JobState.Aborted.ToString(), Color.Orange);
        ganttChart.AddCategory(JobState.Failed.ToString(), Color.Red);
        
        for (int i = 0; i < Content.Count-1; i++) {
          string tooltip = string.Format("State: {0}\n{1} - {2}", Content[i].State, Content[i].DateTime, Content[i + 1].DateTime);
          if (!string.IsNullOrEmpty(Content[i].Exception))
            tooltip += "\n" + Content[i].Exception;
          ganttChart.AddData(0, Content[i].State.ToString(), Content[i].DateTime, Content[i + 1].DateTime, tooltip);
        }
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      // Enable or disable controls based on whether the content is null or the view is set readonly
    }

    #region Event Handlers (child controls)
    // Put event handlers of child controls here.
    #endregion
  }
}
